| Title: | Client for the 'iplookupapi.com' IP Lookup API |
|---|---|
| Description: | An R client for the 'iplookupapi.com' IP Lookup API. The API requires registration of an API key. Basic features are free, some require a paid subscription. You can find the full API documentation at <https://iplookupapi.com/docs> . |
| Authors: | Dominik Kukacka [aut, cre] |
| Maintainer: | Dominik Kukacka <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 06:28:43 UTC |
| Source: | https://github.com/cran/iplookupapi |
Get the current status of the API.
get_api_status()get_api_status()
Returns your current quota. Requests to this endpoint do not count against your quota or rate limit.
Checks the provided IP address (both v4 & v6 formats) and returns all available information.
get_ip_info(ip = NULL, language = NULL)get_ip_info(ip = NULL, language = NULL)
ip |
The IP address you want to query |
language |
An ISO Alpha 2 Language Code for localizing the IP data |
Returns all available information about an IP address.
iplookupapi.com requires authentication via an API key. For this package, the API key is saved as a
environmental variable. In interactive mode, using iplookupapi_api_key
will require you to enter an API key. Alternatively, you can also use
Sys.setenv(IPLOOKUPAPI_API_KEY = <key>) to set the API key manually.
iplookupapi_api_key(force = FALSE)iplookupapi_api_key(force = FALSE)
force |
If |
Returns the set API key that has been stored as an enviroment variable.